@@ -14,17 +14,22 @@ sub api_resource {'addresses'}
 
 sub validate
 {
-    my ( $invocant, $id, $params ) = @_;
+    my ( $invocant, $id, @params ) = @_;
     my $url = $invocant->url( "$id/validate" );
-    my $response = WebService::Shippo::Request->get( $url, $params );
+    my $response = WebService::Shippo::Request->get( $url, @params );
     return $invocant->construct_from( $response );
 }
 
+package    # Hide from PAUSE
+    WebService::Shippo::AddressList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Address:: = *WebService::Shippo::Address::;
+    *Shippo::Address::     = *WebService::Shippo::Address::;
+    *Shippo::AddressList:: = *WebService::Shippo::AddressList::;
 }
 
 1;
