@@ -15,7 +15,7 @@ sub api_resource {'shipments'}
 
 sub rates
 {
-    my ( $invocant, $id, $currency, $params ) = @_;
+    my ( $invocant, $id, $currency, @params ) = @_;
     if ( $currency ) {
         my $validated = $invocant->validate_currency( $currency );
         croak "Invalid currency code ($currency)"
@@ -26,15 +26,20 @@ sub rates
         $currency ||= 'USD';
     }
     my $url = $invocant->url( "$id/rates/$currency" );
-    my $response = Shippo::Request->get( $url, $params );
+    my $response = Shippo::Request->get( $url, @params );
     return $invocant->construct_from( $response );
 }
 
+package    # Hide from PAUSE
+    WebService::Shippo::ShipmentList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Shipment:: = *WebService::Shippo::Shipment::;
+    *Shippo::Shipment::     = *WebService::Shippo::Shipment::;
+    *Shippo::ShipmentList:: = *WebService::Shippo::ShipmentList::;
 }
 
 1;
